View source: R/npi_results_s3.R
| npi_summarize | R Documentation |
npi_results objectS3 method to summarize an npi_results object
npi_summarize(object, ...)
object |
An |
... |
Additional optional arguments |
Missing optional second address lines are treated as empty strings. Missing required address components leave the full address missing.
Tibble containing the following columns:
npiNational Provider Identifier (NPI) number
nameProvider's first and last name for individual providers, organization name for organizational providers.
enumeration_typeType of provider associated with the NPI, either "Individual" or "Organizational"
primary_practice_addressFull address of the provider's primary practice location
phoneProvider's telephone number
primary_taxonomyPrimary taxonomy description. If no taxonomy is marked as primary for a record, the first listed taxonomy is used.
data(npis)
npi_summarize(npis)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.