npi_summarize.npi_results: Summary method for 'npi_results' S3 object

View source: R/npi_results_s3.R

npi_summarize.npi_resultsR Documentation

Summary method for npi_results S3 object

Description

Print a human-readable overview of each record return in the results from a call to npi_search. The format of the summary is modeled after the one offered on the NPI registry website.

Usage

## S3 method for class 'npi_results'
npi_summarize(object, ...)

Arguments

object

An npi_results S3 object

...

Additional optional arguments

Details

Missing optional second address lines are treated as empty strings. Missing required address components leave the full address missing.

Value

Tibble containing the following columns:

npi

National Provider Identifier (NPI) number

name

Provider's first and last name for individual providers, organization name for organizational providers.

enumeration_type

Type of provider associated with the NPI, either "Individual" or "Organizational"

primary_practice_address

Full address of the provider's primary practice location

phone

Provider's telephone number

primary_taxonomy

Primary taxonomy description. If no taxonomy is marked as primary for a record, the first listed taxonomy is used.

Examples

data(npis)
npi_summarize(npis)

npi documentation built on Sept. 6, 2026, 9:06 a.m.