powered by
npi_results
S3 method to summarize an npi_results object
npi_summarize(object, ...)
Tibble containing the following columns:
npi
National Provider Identifier (NPI) number
name
Provider's first and last name for individual providers, organization name for organizational providers.
enumeration_type
Type of provider associated with the NPI, either "Individual" or "Organizational"
primary_practice_address
Full address of the provider's primary practice location
phone
Provider's telephone number
primary_taxonomy
Primary taxonomy description. If no taxonomy is marked as primary for a record, the first listed taxonomy is used.
An npi_results S3 object
Additional optional arguments
Missing optional second address lines are treated as empty strings. Missing required address components leave the full address missing.
data(npis) npi_summarize(npis)
Run the code above in your browser using DataLab