Learn R Programming

npi (version 0.3.1)

npi_summarize.npi_results: Summary method for npi_results S3 object

Description

Print a human-readable overview of each record return in the results from a call to npi_search. The format of the summary is modeled after the one offered on the NPI registry website.

Usage

# S3 method for npi_results
npi_summarize(object, ...)

Value

Tibble containing the following columns:

npi

National Provider Identifier (NPI) number

name

Provider's first and last name for individual providers, organization name for organizational providers.

enumeration_type

Type of provider associated with the NPI, either "Individual" or "Organizational"

primary_practice_address

Full address of the provider's primary practice location

phone

Provider's telephone number

primary_taxonomy

Primary taxonomy description. If no taxonomy is marked as primary for a record, the first listed taxonomy is used.

Arguments

object

An npi_results S3 object

...

Additional optional arguments

Details

Missing optional second address lines are treated as empty strings. Missing required address components leave the full address missing.

Examples

Run this code
data(npis)
npi_summarize(npis)

Run the code above in your browser using DataLab