npi_results S3 objectPrint a human-readable overview of each record return in the results from a
call to npi_search. The format of the summary is modeled after
the one offered on the NPI registry website.
# S3 method for npi_results
npi_summarize(object, ...)Tibble containing the following columns:
npiNational Provider Identifier (NPI) number
nameProvider's first and last name for individual providers, organization name for organizational providers.
enumeration_typeType of provider associated with the NPI, either "Individual" or "Organizational"
primary_practice_addressFull address of the provider's primary practice location
phoneProvider's telephone number
primary_taxonomyPrimary taxonomy description. If no taxonomy is marked as primary for a record, the first listed taxonomy is used.
An npi_results S3 object
Additional optional arguments
Missing optional second address lines are treated as empty strings. Missing required address components leave the full address missing.
data(npis)
npi_summarize(npis)
Run the code above in your browser using DataLab